abs_to_ratio: Convert absolute quantitation to relative ratios.
Description
abs_to_ratio takes a vector of absolute values and
returns a vector of ratios relative to some starting point.
Usage
abs_to_ratio(x, method = "first")
Arguments
x
vector of numeric absolute quantitation values
method
method to use to determine starting value (denominator)
Value
A numeric vector of the same length as input
Details
The denominator used to calculate relative protein concentrations
can affect the ability to model noisy data. In the theoretically ideal
scenario, everything would be relative to the lowest temperature point.
However, other methods can be used to help alleviate problems related to
noise. Available methods include:
"first"
Use the first value (lowest temperature point)
(default)
"max"
Use the maximum value
"top3"
Use the mean of the three highest values
"near"
Use the median of all values greater than 80
the first value