Usage
model_protein(expt, protein, min_rep_psm = 0, min_smp_psm = 0,
min_tot_psm = 0, max_inf = 1, min_score, max_score, smooth = 0,
method = "sum", method.denom = "near", trim = 0, bootstrap = 0,
min_bs_psms = 8, annot_sep = "|", max_slope = 0, min_r2 = 0,
min_reps = 0, only_modeled = 0, check_missing = 0,
missing_cutoff = 0.3)
Arguments
expt
An MSThermExperiment object
protein
ID of the protein to model
min_rep_psm
Minimum number of spectral matches required for each
replicate to model protein
min_smp_psm
Minimum number of spectral matches required for each
sample to model protein
min_tot_psm
Minimum number of spectral matches required across all
replicates to model protein
max_inf
Maximum co-isolation interference level allowed to include a
spectrum in protein-level quantification
min_score
minimum score allowed to include a
spectrum in protein-level quantification
max_score
maximum score allowed to include a
spectrum in protein-level quantification
smooth
(t/F) Perform loess smoothing on the data prior to modeling
method
Protein quantification method to use (see Details)
method.denom
Method used to calculate denominator of abundance
(see Details)
trim
(t/F) Trim all lower data points less than the abundance maximum
bootstrap
(T/F) Perform bootstrap analysis to determine confidence
intervals (slow)
min_bs_psms
Minimum number of spectral matches required to perform
bootstrapping
annot_sep
Symbol used to separate protein group IDs (used for
retrieval of annotations) (default: '|')
max_slope
Maximum slope to consider model (implies "only_modeled")
min_r2
Minimum R2 value to consider model (implies "only_modeled")
min_reps
Minimum number of modeled replicates for each sample to
return protein
only_modeled
(t/F) Only consider modeled proteins
check_missing
(t/F) Run simple test to filter out PSMs with missing
quantification channels where values are expected
missing_cutoff
Minimum fraction relative to surrounding data points
used in the check for missing channels